@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Browser views for documents.
-
-$Id: document.py 110659 2010-04-08 15:54:42Z tseaver $
-"""
+"""Browser views for documents. """
 
 from zope.component import adapts
 from zope.formlib import form
