@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Test Products.CMFDefault.browser.folder
-
-$Id: test_folder.py 110659 2010-04-08 15:54:42Z tseaver $
-"""
+""" Test Products.CMFDefault.browser.folder """
 
 import unittest
 
