@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" Utility functions.
-
-$Id: utils.py 110659 2010-04-08 15:54:42Z tseaver $
-"""
+""" Utility functions. """
 
 from email.Header import make_header
 from email.MIMEText import MIMEText
